#
# spec file for package codelite
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012-2019 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define short_ver 16.0
# Only available on x86_64 and %%arm (see lldb package)
  %ifarch %{arm} x86_64
    %bcond_without lldb
  %endif
# Not available on ppc
  %ifnarch ppc
    %bcond_without clang
  %endif
Name:           codelite
Version:        16.0.0
Release:        2.11
Summary:        Code editor for C, C++, PHP and Node.js
# parts of package contain LGPL-3.0 licenced code thus license needs to be
# GPL-3.0
License:        GPL-3.0-only
Group:          Development/Tools/IDE
URL:            http://codelite.org/
Source0:        https://github.com/eranif/codelite/archive/refs/tags/%{version}.tar.gz
# Template files are identified by RPMLint as Development-Files --> Ignore this errors
Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM  wxStl.patch conrad@quisquis.de -- Fix problem when wxWidgets was compile with wxUSE_STL=1
Patch0:         wxStl.patch
# PATCH-FIX-OPENSUSE  fix_node_env-script-interpreter.patch andythe_great@pm.me -- Fix RPMLINT warning env-script-interpreter.
Patch1:         fix_node_env-script-interpreter.patch
# PATCH-FIX-UPSTREAM  wxStl.patch conrad@quisquis.de -- Fix problem with wx version 3.1.0 and 3.1.1
Patch2:         wxVersion.patch
# PATCH-FIX-UPSTREAM codelite_wxwidgets_3_1_7.patch -- Fix build issues with wx >= 3.1.7
Patch3:         codelite_wxwidgets_3_1_7.patch
BuildRequires:  cmake
BuildRequires:  ctags
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-3_2-devel
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(sqlite3)
Requires:       ctags
Requires:       hicolor-icon-theme
Requires:       xterm-bin
%if %{with lldb}
BuildRequires:  lldb-devel
%endif
%if %{with clang}
BuildRequires:  llvm-clang-devel
%endif

%description
CodeLite is a code editor for the C, C++, PHP and Node.js programming languages.
It uses an interface with which users can create, build and debug projects.

%prep
%autosetup -p1

%build
%cmake \
   %if %{with clang}
  -DENABLE_CLANG=1 \
  %endif
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_INSTALL_LIBDIR=%{_lib} \
  -DCMAKE_SHARED_LINKER_FLAGS="" \
  -DCMAKE_SKIP_RPATH=OFF \
  -DCMAKE_EXE_LINKER_FLAGS="-pie"

%cmake_build

%install
%cmake_install
%__rm %{buildroot}%{_bindir}/ctagsd-tests
%__ln_s -f ctags %{buildroot}%{_bindir}/codelite-ctags
%find_lang %{name}
### Add mime types
mkdir -p %{buildroot}%{_datadir}/mime/packages/
cp -p %{name}.xml %{buildroot}%{_datadir}/mime/packages/
%fdupes %{buildroot}%{_prefix}
### Update translation in desktop menu entry and add IDE as category
%suse_update_desktop_file %{name} IDE

%files -f %{name}.lang
%license COPYING
%doc about.html AUTHORS
%{_bindir}/%{name}*
%{_bindir}/ctagsd
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%exclude %{_datadir}/icons/hicolor/128x128@2x/apps/%{name}.png
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%exclude %{_datadir}/icons/hicolor/256x256@2x/apps/%{name}.png
%exclude %{_datadir}/icons/hicolor/32x32@2x/apps/%{name}.png
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%exclude %{_datadir}/icons/hicolor/64x64@2x/apps/%{name}.png
%{_mandir}/man1/%{name}*.1%{?ext_man}
%{_datadir}/mime/packages/%{name}.xml

%changelog
* Thu Aug 25 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream change to fix build with wxwidgets >= 3.1.7:
  * codelite_wxwidgets_3_1_7.patch
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 16.0.0
  * Added Rust syntax highlight
  * Added new Rust plugin
  * Added new Remote plugin which allows user to load a remote
    "File System Workspace" over SSH
  * LSP: support completion item's doc implemented inside MarkupContent
  * Git Commit List dialog: layout changes. Make the diff window
    occupy half of the dialog
  * clToolBar: honour the wxTB_NODIVIDER style flag
  * use a more sensible colours for highligthing text in the various
    tree / list controls
  * Implemented a custom Menu Bar
    Task view removed. It is now part of the Find In Files dialog
  * Colours and fonts dialog: updating the text selection colours is
    now done for all the languages supported for the currently active theme
  * Fixed: be more tolerant for language server implementations that
    do not implement the protocol as is (e.g. rust)
  * Fixed: externally modified files are not reloaded
  * Remove redundant file system scan
  * Fixed: always pass RootURI when sending Initialize request to the
    LSP server, even if the user did not provide one
  * Fixed: JSON encoding issue
  * Fixed: codelite-terminal does not apply environment variables when
    generating compile_flags.txt file required by clangd
  * Fixed: Linux: Move tab right / left with the keyboard does not work
  * Fixed: file system workspace: in some cases, system scan is not
    working as intended and only scans the top level
  * Fixed: code formatter regression which caused CodeLite to
    override the user's settings
  * Fixed: GTK: right click on tab causes a weird behavior of
    selecting random file
  * Fixed: Implement All Un-Implemented Functions not working when
    header and source are not placed in the same directory
  * Fixed: wxCrafter: "Insert into new Sizer" should not be
    visible for wxAuiManager
  * Fixed: CodeLite Makefile Generator - UNIX: Windows resource
    files are not compiled
  * Fixed: Word completion is broken if a word contains letters
    with diacritics
  * Fixed: "Closed other tabs" -> send "close event" for every
    closed tab
  * Fixed: PHP workspace: allow user to include the workspace or
    project folder when selecting `Find In Folder` from the context menu
  * Fixed: PHP workspace: make it multiple selection
  * Fixed: make sure that the editor folder exists before writing
  * Fixed: C++ workspace: post/pre build events: ignore empty commands
  * Fixed: Feature request: include file extensions for Drupal projects
  * Fixed: Fix Output View multi-byte text handling (rlbxku1r)
  * Fixed: PHP settings: post parse-workspace event only when a
    PHP workspace is opened
  * Fixed: spell checker: when calling "Check" on a file,
    do not uncheck the option of the 'continuous checking'
  * General performance & stability fixes
* Fri Apr  8 2022 Peter Conrad <conrad@quisquis.de>
- Upgrade to upstream 15.0.11
  * Remove codelite-SpellChecker-unnest-classes.patch (obsoleted by upstream)
  * Remove 0001-Fix-compilation-with-recent-glibc-where-SIGSTKSZ-is-.patch (obsoleted by upstream)
  - Remove fix_compilation_JSON_wxWidgets.patch
  * Add wxStl.patch for supporting wxWidgets built with -DwxUSE_STL=1
  * Add wxVersion.patch to fix build with wxWidgets-3.[01].*
  * Expanded fix_node_env-script-interpreter.patch to cover new Runtime/codelite-remote script
  * Upstream changes:
  * Bug fixes
  - Fixed: externally modified files are not reloaded
  - Remove redundant file system scan
  - Fixed: always pass `RootURI` when sending `Initialize` request to the LSP server, even if the user did not provide one
  - Fixed: JSON encoding issue
  - Fixed: `codelite-terminal` does not apply environment variables when generating `compile_flags.txt` file required by `clangd`
  - Fixed: Linux: Move tab right / left with the keyboard does not work
  - Fixed: file system workspace: in some cases, system scan is not working as intended and only scans the top level
  - Fixed: code formatter regression which caused CodeLite to override the user's settings
  - Fixed: GTK: right click on tab causes a weird behavior of selecting random file
  - Fixed: Implement All Un-Implemented Functions not working when header and source are not placed in the same directory
  - Fixed: wxCrafter: "Insert into new Sizer" should not be visible for wxAuiManager (by *rlbxku1r*)
  - Fixed: CodeLite Makefile Generator - UNIX: Windows resource files are not compiled
  - Fixed: "Closed other tabs" -> send "close event" for every closed tab
  - fixed: PHP workspace: allow user to include the workspace or project folder when selecting `Find In Folder` from the context menu
  - fixed: PHP workspace: make it multiple selection
  - Fixed: make sure that the editor folder exists before writing
  - Fixed: C++ workspace: post/pre build events: ignore empty commands
  - Fixed: Feature request: include file extensions for [Drupal projects][2]
  - Fixed: Fix Output View multi-byte text handling (*rlbxku1r*)
  - Fixed: PHP settings: post parse-workspace event only when a PHP workspace is opened
  - Fixed: spell checker: when calling "Check" on a file, do not uncheck the option of the 'continuous checking'
  - Fixed: keyboard shortcuts are now working once again in wxCrafter
  - Fixed: word completion is broken if a word contains letters with diacritics
  - Fixed: avoid restarting any non C++ Language Server when the build process ends
  - Fixed: crash when clicking on the "Link Editor" and no active editor is opened
  - Fixed: colours and fonts dialog: changing the global theme now enables the `apply` button
  - Fixed: Syntax highlight Dialog: when importing a theme, print its name in the completion dialog
  - Fixed: use custom GTK code to get the parent bg colour
  - Fixed: GTK assertions
  - wxCrafter: Fix inconsistent style of option array strings. These strings are now properly wrapped according to the 'Generate Translatable Strings' setting (*rlbxku1r*)
  - wxCrafter: Fix invalid string literal in auto-generated `wxHtmlWindow` code (*rlbxku1r*)
  - wxCrafter: Add missing translations (*rlbxku1r*)
  - Fixed: `codelite-terminal` should now start on `macOS`
  - Fixed: `Quick Add Next` now ensures that if the match is in a hidden line (aka `folded`), it unfold it. fixes: https://github.com/eranif/codelite/issues/2748
  - Git plugin: operations on the tree view now uses the correct repository path
  - Fixed: https://github.com/eranif/codelite/issues/2763 - Goto Declaration/Implementation doesn't work (well) with tabs
  - fixed: on linux, on certain window managers, the tooltip size calculation is smaller than the size required for actually drawing it
  - MSW: don't allow dark mode for text controls
  - Removed the non maintained Notebook style: `TRAPEZOID`
  - Fixed: [Wrap with brackets option not working][fixes: https://github.com/eranif/codelite/issues/2822]
  - Find Replace Bar: fixed issue with no Latin charcters
  - Fixed: code completion tooltip generated by the CTags code completion engine are not compatible with markdown syntax
  - Fixed: function hover tip should not be rejected by the file system workspace (*rlbxku1r*)
  - Fixed: changing the zoom in one editor, applies it to other editors as well
  - CodeLiteDiff fixes
  - Code Formatter: various fixes to `clang-format`
  - Fixed: `Close other tabs` context menu entry, does not attempt the modified `this` tab
  - Fixed navigation bar persistency issue (*rlbxku1r*)
  - Fixed: `Remoty`: when `Remoty` is enabled, typing in the `Remote path` field manually, causes CodeLite to crash
  - Fixed: Create New C++ Project: do not prompt the user to switch to `CodeLite Makefile Generator - UNIX` when using GCC from the **MinGW** MSYS repository
  - Fixed: navigation bar commit message does not update with when changing lines
  - Fixed: Syntax Highlight: clicking on the `Restore Defaults` button, will now restore the previous font + selected theme
  - Fixed: GNU make & bash builder: Fix error with parent directory name containing spaces (*rlbxku1r*)
  - Fixed: CodeFormatter: `Export .clang-format file` points to the workspace directory by default
  - Fixed: Debugger: Fix a regression that the setting `Use CTRL key to evaluate expressions under the cursor` doesn't remember its value
  - Fixed: Project Settings: Don't try to save or clone an unnamed compiler
  - Fix Search & Replace for UTF-8 string
  - Fixed: GTK: at times, right clicking inside an editor might trigger the tab control context menu this could happen when right clicking near the top edge of the editor.
  - Fixed: GTK: output view/workspace view: choosing "hide" or "detach" from the tab context menu for a non active tab, would perform the selected action on the active tab
  * Improvements
  - Fixed: be more tolerant for language server implementations that do not implement the protocol as is (e.g. rust)
  - Added `Rust` syntax highlight
  - LSP: support completion item's doc implemented inside `MarkupContent`
  - Added **new** `Rust` plugin:
  - Debugger support via `rust-gdb`
  - Project management
  - Code completion via the Language Server Plugin using the `rls` server or the `rust-analyzer` LSP
  - Build output is clickable and allows user to quickly open problematic source files
  - Git Commit List dialog: layout changes. Make the diff window occupy half of the dialog
  - clToolBar: honour the `wxTB_NODIVIDER` style flag
  - use a more sensible colours for highligthing text in the various tree / list controls
  - Implemented a custom Menu Bar
  - General performance & stability fixes
  - Added new Remote plugin which allows user to load a remote "File System Workspace" over SSH
  - Task view removed. It is now part of the Find In Files dialog
  - Colours and fonts dialog: updating the text selection colours is now done for all the languages supported for the currently active theme
  - **Remoty plugin**: use the newly added `codelite-remote` interface which allows using various plugin on a remote machines:
  - `Git`
  - `find in files`
  - `Language Server Plugin` over SSH
  - Diff plugin
  - UI updates
  - Added new tab control style: `FIREFOX` (screenshot below)
  - Build tab output rewritten: it now honours the terminal colours
  - Git plugin log view re-written and it now uses the same control as the build output, which honours the terminal colours
  - Project Settings: Improve dirty settings detection (*rlbxku1r*)
  - Project Settings: Use `append` by default for PCH flags option (*rlbxku1r*)
  - `clangd` + `clang-format` that comes with CodeLite for macOS and Windows are now using version `12.0.0`
  - File System Workspace: support multi-line commands in the build pages
  - When using the file system workspace, export a special enviroment variable `CXX_INCLUDE_PATHS` this variable contains a list of compiler search paths for header files, separated by `;` is useful when using `CMake` + `MinGW` + `file system workspace` under windows, where the `CMAKE_EXPORTS_COMPILE_COMMANDS` does not include the compiler search paths, which breaks `clangd` code completion
  - GDB-MI output parser re-written to support custom file paths with unusual characters
  - VIM:Add some new commands (`~`, `o`, `O`) (mx)
  - When importing themes with true black colour as their background colour, soften the it a bit
  - git plugin: better support for remote repository where the workspace is not set in the root folder of the workspace
  - change the location of CodeLite temp folder into `/tmp/codelite/PID`. This should reduce the spam under the `/tmp` folder
  - Support drawing multiline text in the clTreeCtrl
  - Code completion entry tooltip: CodeLite now supports Markdown rendering
  - New project wizard: more fixes to avoid problems when using `MSYS2` compiler on Windows (*rlbxku1r*)
  - wxCrafter: Fix wrong tree order on the first sibling widget duplication (*rlbxku1r*)
  - LSP `Find Symbol`: Make text selection `UTF-8` aware
  - Multiple tooltip Markdown renderer fixes (*rlbxku1r*)
  - Colouring of semantic tokens is now done by the Language Server plugin
  - Updated the default themes that comes with CodeLite
  - C++ context menu: `Find Declaration` & `Find Implementation` entries are now replaced withe single, intelligent `Find Symbol` entry
  - [Implemented: Feature request: "Open resource" dialog should support optional [:line[:column]] "coordinates"][3]
  - New: added an option to highlight the current line number (in the line number margin)
  - C++ workspace dialog updated
  - `MINIMAL` and `DEFAULT` tab design refreshed
  - Build tab: added `Copy all` context menu entry
  - Find bar: the search logic re-written from scratch. With the old search, replacing 1000+ string instances using `Replace All` on a file with size of 6MB took roughly 45 seconds (On Windows machine, 32GB memory and 24 cores)    With the new code (which performs in-buffer replacement where it can) this takes roughly 300ms!
  - CodeLite logo updated
  - C++ new class wizard: use `C++11` features (*rlbxku1r*)
  - C++ parser: fix parsing class with `final` (*rlbxku1r*)
  - C++ parser: accept `C++17` nested namespaces (*rlbxku1r*)
  - Improve compiler detection code (*rlbxku1r*)
  - Semantic highlight should now work on files opens via `Remoty`
  - Identify files starting with shebang `#!/usr/bin/env python3` as python files
  - Various `codelite_indexer` fixes: (*rlbxku1r*)
  - accept `C++11` type alias
  - accept `C++11` `final` keyword
  - accept `C++11` `alignas` keyword
  - accept `C++11` `noexcept` keyword
  - Accept `C++17` nested namespace notation
  - Properly collect using aliases (e.g. `using std::shared_ptr;`)
  - Script language keywords updated to include: `local`, `function`, `exit` and `return`
  - Remoty: support for auto detection of: `pylsp` language server
  - SFTP: attempt to compare checksums before re-downloading file from remote server
  - Recognize `.ts` files types (`TypeScript`)
  - Code cleanup: removed all `tern` code completion code, use `typescript-language-server` instead
  - Added new language server tab to log LSP messages of type `logMessage`, `telemetry` and `showMessage`
  - File types: `patch` and `diff` are now properly identified by CodeLite
  - Better dark theme support for Linux built with `-DWITH_NATIVEBOOK=0`
  - Language Server Plugin: implement semantic highlight (`textDocument/semanticTokens/full`) using the `textDocument/documentSymbol` message
  - Updated the colour themes
  - Source code formatter: added an option to disable the formatting engines
  - Lexer: separate JSON from the JavaScript file
  - CodeFormatter: added basic JSON formatter
  - Handle various workspace files (`NodeJS`, `Docker`, `FSW`, `Rust`, `Remoty`) as `JSON` files
  - The 'best project settings' for certain builders can be obtained from the builder object. (*rlbxku1r*)
  - Auto-detect and set the output file extension (exe, lib, dll, a, so, dylib) for given project type. (*rlbxku1r*)
  - Colour `.toml` files as `INI` files ("properties")
  - Remoty: re-wrote the "Open workspace" dialog
  - SFTP browser dialog: if the path in the "Browse" entry is a file path, remove the file name and just open the folder
  - Add option to enable spell checking on wxTextCtrl from within wxCrafter (*iwbnwif*)
  - [Allow the user the change the active project from the menu (Workspace -> Set active project) or from the "Goto Anything" dialog (`Ctrl-Shift-P`)][4]
  - Language Server Protcol: implemented `Hover` request message
  - Language Server Protocol: implemented `Find references`. This feature will only be shown for Language Servers that support it like
  - `clangd`
  - `python-lsp`
  - `typescript-language-server`
  - `rust-analyzer`
  - The old code completion was removed from CodeLite (`codelite_indexer`), instead, we now provide our own C++ language server named `ctagsd` which a re-written from scratch code completion engine with excellent C++11/14 features
  - Line margin: highlight the current line, in addition this feature performance is now in `O(1)` and is not depend on the size of the opened file
  - Editor track changes: re-designed. Modified lines / saved lines are now marked using [dedicated line number colour][5]
  - Colours: CodeLite now offers to ability to import VSCode themes (in the JSON format)
  - We now provide wxCrafter standalone builds for Windows / GTK (experimental)
  - wxCrafter: allow to keep sizers are members
  - wxCrafter: fixed: crash when clicking on `Select virtual directory` while in standalone mode
  - wxCrafter: event handlers are now using the `wx3.0` syntax of `Bind()`/`Unbind()` instead of `Connect()`/`Disconnect()`
  - wxCrafter: by default, generate `.hpp` files instead of `.h`
  - Remoty plugin: the way it launches language servers on the remote machine has changed. [See the docs for more details][6]
  - Improved file syntax using the shebang
  - Make the `Preferences` dialog more native to the host OS
  - Added an option to enable/disable the newly added feature of highligting the current line number. This should allow CodeLite running on older machines with bad graphics cards to run smoother
  - Improved type info tooltips (`ctagsd`)
  - Find Bar: use the same text control as the main editor instead of `wxTextCtrl`
* Sun Jan 30 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add codelite-SpellChecker-unnest-classes.patch -- Un-nest 2
  nested classes: this fixes compilation with g++ 11.2.0;
  patch taken from upstream commit and re-based for current
  version (deb#997219).
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Backport change from cppcheck:
  * 0001-Fix-compilation-with-recent-glibc-where-SIGSTKSZ-is-.patch
* Sat Mar  6 2021 andy great <andythe_great@pm.me>
- Update to version 15.0.0.
  * bug fixes
  * Fixed: hiding line number margin is no longer possible
  * Find In Files: should now load faster on Windows
  * Fixed: File System Workspace: keep the last 'File mask'
    value used
  * Language Server Protocol: Initialized notification to the
    server
  * Prevent hangs under Wayland when changing Workspace View
    tabs
  * Properly save/load workspace breakpoints and avoid mixing
    between two different workspaces breakpoints
  * File System Workspace: when 'remote development' is enabled,
    do not attempt to remote save a file that is not part of our
    source tree or was opened by the SFTP plugin
  * Fixed: crash when switching between themes
  * gdb does not display local variables properly
  * Creating a new file from the context menu in the File System
    Workspace - does not add it to git or svn
  * Outline: honour the general background theme colour
  * Bootstrap wizard: if the user select Default profile, load
    all plugins
  * Fixed crash in codelite-terminal when executed with
  - -command
  * Fixed: SFTP overrides file attributes if these were modified
    after the file was loaded into CodeLite
  * LLDB settings: keep the full path for debugserver
  * Fixed: cppcheck is now working from the context menu again
  * File System Workspace: set the default working directory to
    the workspace folder
  * PHPdoc return value is not handled correctly
  * Changes
  * Displaying the parent folder in the tab label is now optional
  * Git push: just execute git push without prompting the user to
    select remote
  * By default, show minimal list of buttons in the toolbar when
    first time installing CodeLite
  * By default, enable minimal list of plugins (by profile type)
  * File System Workspace: split the settings into 2 different
    files: a local and shared file. The content in the "local"
    files is kept under .codelite/ directory in the workspace
    folder and is not to be saved into git or any source control
    the * default .workspace file contains properties that should
    be shared
  * File System Workspace: added 'working directory' field
  * Language Server Protocol: optimized the traffic between
    LSP <-> CodeLite by adding checksum checks before calling LSP
    to re-parse a file
  * Language Server Protocol: added support for implemented
    'extDocument/documentSymbol' protocol message
  * PHP: update PHP xdebug UI view to fit the IDE look
  * Language Server Protocol: added an option to pass environment
    variables + initialization options directly from the UI
  * GDB: Honor user's ~/.gdbinit file
  * File System Workspace: added an option to use remote build
  * Internal changes to how GDB communicate changes to CodeLite
  * Appearance: honor *system* dark themes
  * Language Server Protocol: install the user code completion
    provided by clangd automatically
  * Creating or deleting a folder via the 'Explorer' view, will
    automatically sync PHP workspace
  * file system workspace: extend the default file extensions to
    show with *.py, *.rb, *.php and *.php
  * python support: adjust method document style to match the
    NumPy method as described here:
    https://docs.python-guide.org/writing/documentation/
  * [PHP] Find functions in context when inserting PHPDoc
  * [PHP] Add return type to signature
  * [PHP] Add nullable type to signature in auto-complete
  * [PHP] Hint nullable and default values
  * [PHP] Handel parsing of by reference values in PHPDoc
  * [PHP] Allow parsing of nullable types from PHPDoc
  * [PHP] Handle parsing PHP 7.1 nullable types
  * [PHP] Handle common mistakes when parsing PHPDoc
  * [PHP] Add missing native types
  * [PHP] Group tags in generated PHPDoc
  * [PHP] Set return type to mixed when unspecified
  * Callgraph is no longer included in the default installer of
    CodeLite
  * File System Workspace: added the ability to exclude folders
    from the workspace. The folders are still visible, but they
    will be excluded in * various operations, like Find In Files,
    Parsing etc
  * Full parsing of workspace is roughly 30%% faster now
  * Renamed default build system from "CodeLite Make
    Generator" -> "CodeLite Makefile Generator"
  * Added new Build System: CodeLite Makefile
    Generator - UNIX - which generates UNIX compatible Makefiles,
    even when on Windows (useful for cygwin / MSYS environments)
  * contextual highlight is no longer done using the SQLite
    symbol database, as a result it should feel much more faster
  * Git reset: added a WARNING icon to the dialog + Cancel
    button (which is now the new default)
  * Navigation bar now also displays "git blame" info
    (author + commit hash + date) for the current line
  * UI updated to the Preferfences and Colour and fonts dialog
  * Refined dark theme support by removing various border which
    might look bright on dark theme
  * Language Server Plugin: you can now mark an LSP as SSH. This
    will execute it on a remote machine instead (you still need
    to make sure that it is installed on the remote machine)
  * Quick Debug: it is now possible to debug over SSH from. Just
    state the account + binary to debug and CodeLite will do the
    rest
  * Language Server Plugin: opening a header file will now
    automatically send the implementation file (cpp) to the active
    LSP for parsing. This way we make sure that goto-definition
    will work immediately
  * Implemented a proper "switch to workspace" functionality.
    It is now possible to call Open Workspace without the need
    to the currently opened one. In addition, CodeLite will now
    display a dialog that will list the last opened workspaces
  * PHP Find In Files: 1. Starting find-in-files from the context
    menu will force the find-in-files dialog to use the selected
    dialogs from the tree view *this are transient paths and will
    not be remembered* 2. Starting find-in-files from any other
    way, will use the last used settings
  * Fixed: find in files offset is broken when non ASCII text is
    presented in the editor
- Rebase fix_compilation_JSON_wxWidgets.patch.
* Wed Nov 25 2020 andy great <andythe_great@pm.me>
- Update to version 14.0.2.
  * Increased the external tools limit from 10 -> 20
  * wxCrfater: Wrap the include statements part of the generated
    code with // clang-format {on|off} block this will disable any
    include sorting done by clang-format which might break
    compilation
  * New project dialog re-written and simplified
  * Diff View : added "find" command
  * Added menu option: Help -> Report an issue
  * Various font fixes in the code completion windows
  * Diff frames now start maximized
  * Diff View: all the toolbar commands can now be executed from
    the keyboard
  * New build system. the old Default was renamed and now is called
    Default (DEPRECATED). The new build system performs a full out
    of the source tree build. The entire build artifacts are placed
    in a single folder under the workspace path, this is similar to
    CMake
  * New workspace type introduced: The File System Workspace
    see: https://wiki.codelite.org/pmwiki.php/Main/FileSystemWorkspace
  * Improved startup time by reducing the number of syscalls
    significantly
  * Language Server Protocol: discard code-completion responses if
    a new request was already sent to the server
  * Use PATH to search binaries instead of hard coded /usr/bin/
    path
  * UI: Updated the tabs drawing (mainly the "DEFAULT" and the
    "MINIMAL" styles)
  * wxCrafter: UI update: the right side view no longer has a
    splitter, instead it only uses tabs
  * Debugger->Attach to process dialog: the process ID is now also
    used for filtering
  * File System Workspace: save all modified files before the build
    starts
  * Increase the code completion box width
  * Restart all LSP once a build process is completed
  * SFTP: once we open the SFTP browser to view a remote server,
    keep the session
  * Simplify the LSP configuration dialog
  * UI updates to the tab drawings
  * Language Server Plugin: support for auto inclusion of missing
    headers
  * Language Server Plugin: auto detect ( by clicking the Scan
    button ) installed LSPs currently supported:
    `python-language-server` and `clangd`
  * VIM plugin imporvements
  * New Class dialog simplification
  * Outline tab: remove the search text control, you can now use
    Ctrl-F search a symbol
  * Fixed clang compiler detection. On OSX, also search for clang
    compiler installed by brew
  * Bash editor: make $ a valid word character
  * More DPI aware changes
  * File System Workspace: dont use the 'Quick Debug' for starting
    debug session
  * File System Workspace: store the breakpoints when the
  workspace is closed
  * File System Workspace: add an option to choose debugger in
    the settings dialog
  * Code completion: don't add extra > or " when choosing an entry
    from the #include completion list
  * Code completion: constructor items are marked with the proper
    icon in the completion list
  * Code completion: template items are now completed in the
    editor in the form of: vector<|> where "|" marks the caret
  * Quick Find All / Add Next (Ctrl-K) -> honour the find bar
    options (wholeword, match case etc)
  * LSP: added an option to restart the LSPs
  * Performance improvements
  * Auto search and detect LSP (clangd, python)
  * C++ parser thread will now parse also files without standard
    C++ extension which defined as such under
    'Settings->Code Completion->General'
  * Visual updates to the 'Replace In Files' view
  * GDB: limit the number of displayed elements of arrays / object
    with a configurable value. The default is set to 100
  * File system workspace: added an option to hide specific file
    types from the view, with reasonable defaults:
    "*.o;*.pyc;*.obj;*.workspace;*.o.d;*.exe;*.dll;*.project"
  * Python: typing """ followed by an ENTER, generates and insert
    a block comment
  * Python: support Ctrl-/ and Ctrl-Shift-/ for inserting block /
    line comments
  * Docker: auto detect docker binaries
  * Docker: make the 'build' Dockerfile command work out of the
    box without setting anything in the 'Build' tab
  * LSP plugin: added 'Find Symbol' to the editor's context menu
  * Fullscreen is now persistent between restarts
  * SFTP plugin: support ssh-agent
  * Language Server Plugins: support connecting an already running
    LSP server (can be on a remote machine)
  * Reload File: keep the folding + bookmarks set on the file
  * Separated between the 'smart paren/bracket' and 'auto add
    closing paren/bracket' functionalities in the UI. i.e. these
    2 now have 2 different checkboxes in the UI
  * C++ class generator: use .hpp file by default instead of .h
  * When loading wxCrafter view, expand the top level node item
  * C++ class wizard: support file system workspace
  * Give the git log dialog a Close button
  * Make the dialog Close when ESC is pressed
  * When offering a list of possible terminals in
    Settings > Preferences >Terminal, don't include ones that are
    not currently available on the user's system
  * wxCrafter: should now also be working with File System
    Workspace
  * CodeLite's SFTP plugin now uses ssh-agent
  * The stop build button in the c++ workspace's mini toolbar was
    removed. The build button now changes its icon to 'stop' while
    a build is in progress
  * C++ workspace: added the option to stop an executed program
    from the mini workspace toolbar
  * Debugger: use better default values
  * Auto prompt for LSPs when first time installing CodeLite
  * codelite-make keeps coredumping when using a project with a
    custom makefile
  * View Navigation Bar hotkey does not toggle check mark
  * Regression: C++ open resource allows multiple selection
  * How to make Navigation Bar appear by default ?
  * Subversion plugin : path information missing
  * Fixed: codelite crash when deleting the last panel in main box
    sizer, or delete the main box sizer
  * Fixed: GDB shows a message box when SIGPIPE is captured
  * Debugger doesn't work on Mac with codelite
  * Debugger doesn't show backtrace when program receives SIGPIPE
  * Fixed: Language Server plugin can now handle binary output
    returns from the various servers (e.g. clangd in some cases
    returns binary data integrated into the completion results)
  * Fixed: find in files output is now sorted by A-Z
  * Changing font for build ouptut window does not work
  * Fixed: failed to start LSP server when the command contains
    spaces with backslashes in it (e.g. "C:\Program Files\..."
  * Fixed: project settings (C++): hitting ENTER in the environment
    page, dismisses the dialog
  * Unable to create new project
  * Fixed: find in files hangs when Enable pipe filter is checked
    and the content before the first pipe is empty
  * Fixed: Pressing keyboard LEFT arrow in tree views does not jump
    to parent node
  * Fixed: delay on tab switching on GTK3 with slow machines
  * Implemented handling for SQLite error: disk I/O error
  * https://github.com/eranif/codelite/issues/2408
  * Fixed: delay on tab switching on GTK3 with slow machines
  * Implemented handling for SQLite error: disk I/O error
  * wxCrafter Panel Cannot be resized correctly
  * Gnome terminal does not work casued by
    4e270fb42bd8b1a8f5fc72817cda9005e8ea44e4. Change it back.
  * Fixed: when choosing a template function from the code
    completion, the inserted code block is shuffled
  * File System workspace: update the files cache when a new file
    is created
  * Fixed possible buffer overflow
  * Fixed: SFTP bookmarks does not work
  * clDiffFrame, used e.g. by git Diff View, can now be closed with
    the ESC key
  * Make Ctrl-C in the Output tab of the Debugger Panework work
    again
- Updates since 12.0.0.
  * Make alphabetical sorting of the Notebook tabs' dropdown menu
    optional from settings->preferences->windows & tabs
  * Remove the Trace output tab. Instead of the Trace tab, all the
    log messages are now redirected to CodeLite log file
    ~/.codelite/codelite.log
  * Spell checker plugin "Continuous" mode is now persistent
    between runs
  * Make Ctrl-C over an empty line copying the entire line optional
  * spellcheck: a bit more false positive reduction in continuous
    mode
  * Navigation bar: allow the user to place it below or above the
    editor control
  * (feature request) Show number of chars and/or bytes in text
    selection in the footer
  * (feature request) Add possibility for renaming folders
  * lldb: added run-to-caret and jump-to-caret.
  * lldb: added option to dislay thread name to threads pane
  * lldb: added add watch context menu in editor and remove watch
    context menu in locals view
  * lldb: expanded locals recursively and don't re-expand
    previously collapsed items
  * lldb: added a thread context menu with suspend/resume.
  * lldb: quickly add inner class members into the watch view
  * lldb: support changing the display format (similar to gdb)
  * Make the Ctrl-TAB and Ctrl-Shift-TAB configurable
  * Feature Request: move editor tab left/right functionality
  * subversion plugin : cannot handle unversioned files
  * Feature request: Find In Files: all files relative from
    workspace (and down)
  * wxCrafter: added support for subclassing wxToolBar and
    wxAuiToolBar
  * New Notebook style was added
  * Detach Editor now allows to DnD editors from the main notebook
    to the detached frame
  * Database explorer UI revamped
  * Support customizing the captions colours
  * Added syntax highlight for Dockerfile
  * New plugin: Docker, now edit build and execute Docker
    containers from CodeLite
  * ToolBar: support customisation
    (choose which tools are displayed)
  * CodeLite is now more friendly with the dark themes
  * Use new controls for trees and table based views
  * Allow building a header file (by compiling its CXX counterpart)
  * Don't execute post build commands when compiling a single file
  * Adjust doxygen settings when using /*!
  * Make CodeLite compile and run against GTK3
  * All bitmaps were replaced with a consistent clear bitmaps
    (two sets created: for dark and normal themes)
  * Terminal support in CodeLite simplified. There is a single
    location where you can choose which terminal
    (from a predefined list of terminals) to use, this selection
    now affects all terminals launched by CodeLite
  * wxCrafter: support wxMiniFrame
  * WebTools plugin: Node.js debugger re-written to support newer
    versions of Node.js
    (The Node.js project changed the debugger protocol)
  * The debugger toolbar is now a floating toolbar that shows when
    debug session starts
  * No more splash screen
  * Find in Files dialog feature req
  * It is now possible to perform find in files in the SFTP tree
    view
  * CppCheck updated to version 1.85
  * CodeLite now accepts folder path as a command line argument and
    opens it in the "Explorer" view. If a workspace file exists in
    the path given, the workspace is loaded instead of opening the
    folder
  * Support document code completion (i.e. hitting Ctrl-Space in a
    block comment will suggest the various document keywords
    (e.g. @param @brief etc.)
  * NodeJS debugger: added the ability to copy the backtrace into
    the clipboard
  * Implement PHP comments fold
  * Added support to Language Servers
  * Find In Files: the Look In and File mask fields are now kept
    and loaded per workspace type. Sensible defaults are used per
    workspace
  * Find In Files: the Look In field is now a free text field
  * Language Server plugin: auto restart the LSP once new
    compile_commands.json is generated
  * New plugin: EOSWiki - support blockchain development using
    EOSIO
  * Find In Files: allow to exclude folder from the search by using
    wild card syntax. For example, to exclude all content from
    node_modules folder, you can add to the Look In field this
    line: -*node_modules*
  * Better dark theme support for OS with no dark theme
  * CodeLite diff plugin: support folders diff Ctrl-Alt-F by
    default.
  * Added support for pinned projects view. A pinned projects gives
    a quick access to the project context menu without the need to
    search for the project item in the C++ workspace view
  * Files opened via the SFTP no longer displays the "cloud" icon
  * Allow spell checker plugin to work with multiple CodeLite
    instances
  * Fixed: Ctrl-Shift-P -> Svn Commit does not work
  * Fixed: Checking "Use Codelite's built-in terminal emulator"
    requires uninstall/reinstall
  * Fixed: crash when editing keyboard shortcut
  * Fixed: Doxygen tweaks use wrong line ending
  * Fixed: OSX: at times, the nodejs debugger did not start
  * Copy & paste functions in SVN Commit dialog are not available
  * Right clicking on vdir with physical one does not default new
    template wizard to that directory
  * New Class and New Template Wizard do not enforce same filename
    case
  * wxCrafter: Fixed: when using in frame mode, make sure that all
    dialogs shown from wxC, are parented to this main frame and not
    CodeLite's one
  * wxCrafter: Fixed: Top level windows (Frame, Dialog and Top
    level Panel) did not honor the common properties (bg colour,
    fg coluor, hidden, focused and disabled state)
  * wxCrafter: Fixed: When in frame mode, use CodeLite' wxAUI
    docking art for UI persistency
  * wxCrafter: Fixed: All generated files are now formatted
    according to CodeLite's formatter settings
  * wxCrafter: Fixed: Honor the "Format Inherited Classes" setting
    property
  * Fixed: debugger arrays are displayed incorrectly in the Locals
    & Watches view
  * Fixed: code completion window is not positioned correctly on
    multiple screens with different resolutions
  * Fixed: unable to select virtual directory in various wxCrafter
    dialogs
  * When starting CodeLite from the command line with a file name
    as input, don't show the welcome page
  * Fixed: creating a C++ workspace by dragging a folder from the
    file manager does not work if the folder has special chars in
    it's name
  * Fixed: Memcheck generates malformed XML file path, cannot
    create file and fails to start
  * Fixed: codelite-make broken
  * Fixed: CMake plugin regression (missing double quotes in the
    generated link_directory entries)
- Add fix_compilation_JSON_wxWidgets.patch to work around wxWidgets
  builds on openSUSE cause Codelite to fail to compile.
  gh#eranif/codelite#2649
- Add fix_node_env-script-interpreter.patch, Fix RPMLINT warning
  env-script-interpreter.
- Remove codelite-disable-new-version-check.patch, not applicable.
- Fix position-independent-executable-suggested by adding -pie flag.
* Mon Mar 18 2019 Mariusz Fik <fisiu@opensuse.org>
- Fix again rpath for plugins.
* Fri Mar  1 2019 Martin Pluskal <mpluskal@suse.com>
- Small packaging cleanups
* Tue Feb 26 2019 Francescodario Cuzzocrea <francescodario.cuzzocrea@mail.polimi.it>
- Update to upstream version 12.0:
  * Plenty of changes - see https://wiki.codelite.org/pmwiki.php/Main/ReleaseNotesCodeLite12
- Remove upstreamed patches"
  * fix-use-system-sqlite3.patch
  * fix-no-return-in-nonvoid-function.patch
* Mon Nov  5 2018 Martin Pluskal <mpluskal@suse.com>
- Fix changelog
- Run spec-cleaner
- Drop conditions for old distros
* Mon Oct 29 2018 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from description.
* Sat Oct 27 2018 fisiu@opensuse.org
- Don't disable rpath, plugins need that
* Mon Mar 21 2016 mpluskal@suse.com
- Install COPYING
* Sun Oct 11 2015 mpluskal@suse.com
- Use cmake macros
- Remove conditonals for unsupported releases
- Simplify bconds and enable lldb and llvm by default on Factory
* Mon Oct  5 2015 rpm@fthiessen.de
- Update to upstream version 8.1:
  * Removed upstream merged: codelite-date-time-usage-fix.patch
  * Cleanup SPEC, new dependencies added and workarounds removed.
  * Using bundled version of .desktop, removed our codelite.desktop
  * Added fix-use-system-sqlite3.patch to use system sqlite3
    version instead of the version from codelite. Fixed already
    upstream in git commit: fe554119c772d8579094b2c3315e0bab92cd4afe
  * Added fix-no-return-in-nonvoid-function.patch to avoid RPMLint
    error, because of non void function without return.
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in postun scripts
* Tue Sep 23 2014 sfalken@opensuse.org
- Removed %%wx_requires as it is no longer a valid macro
* Tue Mar 18 2014 fisiu@opensuse.org
- Fix source tarball url.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.4:
  + New cmake plugin.
  + New tweak plugin.
  + Improved git plugin.
  + codelite-terminal: new terminal emulator.
  + Many enhancements and bug fixes.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.3:
  + Brand new SFTP plugin.
  + codelite-make: a command-line tool to generate Makefiles from codelite's
    project.
  + Improved git, database explorer, cscope and Wizard plugins.
  + Bug fixes.
* Fri Nov  8 2013 fisiu@opensuse.org
- Change previous cmake parameter to -DCMAKE_SKIP_RPATH=ON. Fix bnc#848791.
* Thu Sep 12 2013 toganm@opensuse.org
- add -DCMAKE_SKIP_INSTALL_RPATH=ON to cmake options
* Tue Jul 16 2013 fisiu@opensuse.org
- Update to 5.2:
  + Added disassemble window to the debugger
  + Better dark theme visualization
  + Improved tab appearance
  + Debugger pretty printing improvements
  + Various dialogs were re-designed (setters/getters)
  + Improved code completion
  + and much more
- Enable db explorer plugin with mariadb/mysql support.
* Wed Jun 12 2013 dvaleev@suse.com
- Add llvm-clang-devel to buildrequires, so the archs other than
  x86 would find -lclang
* Mon May 27 2013 fisiu@opensuse.org
- Change license to GPL-3.0+, fix bnc#821637.
* Thu May 16 2013 fisiu@opensuse.org
- Enable manual stripping for SLE.
* Wed May 15 2013 fisiu@opensuse.org
- Fix missing license's text in About dialog.
* Wed Apr 10 2013 fisiu@opensuse.org
- Update to 5.1:
  + Build with CMake
  + Czech translation
  + New highlight theme "Zmrok-like"
  + Improved git support
  + Code completion enhancements
  + Many bug fixes
- Patch codelite-4.1.5770-disable-autoupdate-by-default.patch was
  updated and renamed to codelite-disable-new-version-check.patch
* Fri Feb  1 2013 fisiu@opensuse.org
- Update to 5.0.6213:
  + Support for GUI RAD wxCrafter: http://wxcrafter.codelite.org
  + New plugin Zoom Navigato
  + New "New Project" dialog
  + Quick code navigation with Shift-Click (configurable)
  + Various updates to code completion
  + More bugs fixed
- Drop codelite-no-return-fix.patch: fixed upstream
- Codelite needs wxWidgets >= 2.9.4
* Tue Sep 25 2012 svalx@svalx.net
- Update to 4.1.5770:
  + "Symbol View" is now deprecated infavor of the "Outline" plugin
  + Clang code completion improvements:
  + Codelite's Makefiles are more standard (they are now using the
    standard CXX, CC, AR, CFLAGS and CXXFLAGS variables).
- Add codelite-no-return-fix.patch for fix
  no-return-in-nonvoid-function error
- Build on SLE11-SP2 whith wxGTK 2.8.8
- Add codelite-4.1.5770-disable-autoupdate-by-default.patch.
- Add some fields to desktop file.
- Changes in spec file:
  + Add MIME types for workspace and project;
  + Remove URL path from source0;
  + Use %%{__make} macros;
  + Remove duplicate GPL file from %%{_datadir};
  + Add some configure options;
  + Add %%clean section.
  + Manual strip binaries for SLE11-SP2
* Tue Jun 19 2012 fisiu@opensuse.org
- Update to 4.0.5589:
  + Enhanced support for svn, works with svn 1.7.
  + Items in debugger tooltip are editable.
  + Support for clang up to 3.2.
  + C++11 completion can be turned ON/OFF.
  + New icon set added.
  + Added CallGraph plugin.
* Sat Apr  7 2012 fisiu@opensuse.org
- Update to 3.5.5375:
  + Code completion speed improvements.
  + An improved clang code completion (with libclang).
  + New perspective management.
  + Many bug fixes.
  + Infrastructure improvements.
- Add codelite-date-time-usage-fix.patch.
* Mon Jan 24 2011 fisiu@opensuse.org
- build against wxWidgets-wxcontainer-devel instead wxGTK-devel for
  openSUSE > 11.3
* Mon Jan  3 2011 fisiu@opensuse.org
- upstream update to 2.9.0.4684:
  + Many bug fixes
  + Subversion plugin enhancements
  + Improved debugging
* Mon Nov  1 2010 fisiu@opensuse.org
- upstream update to 2.8.0.4537:
  + Many bug fixes
  + Debugger interface revamp
  + Find In Files improvements:
  - New options: ignore matches founds in comments or string
  - Color matches in comments using the editor's comment color
  + New: 'Find References'
* Wed Oct 13 2010 fisiu@opensuse.org
- upstream update to 2.7.0.4375:
  + Many bug fixes
  + New look
  + Code completion enhancements ( Macros improvement, More complex templates handling and much more )
  + New refactoring: Rename Local Variable
* Wed Jun  9 2010 fisiu@opensuse.org
- upstream update to 2.5.3.4075
  + code completion enhancements
  + many bugs were fixed
* Mon Apr 12 2010 fisiu@opensuse.org                              
- upstream update to 2.5.2.4031
  + Introducing wxAUI docking system + notebooks
  + Improvements to the debugger
  + code completion enhancements
  + Many UI changes
  + Many bugs were fixed
* Wed Mar  3 2010 fisiu@opensuse.org                              
- upstream update to 2.3.0.3833
  + Major improvements in the Code Completion
  + SymbolView plugin
  + Simplified search methods
  + Many bugs were fixed
* Tue Feb  2 2010 fisiu@opensuse.org
- upstream update to 2.2.0.3681
  + Introducing the environment variables set - define environment variable set per workspace
  + Subversion plugin - many bug fixes + improvements
  + Incremental search: Now with Replace options!
  + Improved function calltip
* Tue Jan 19 2010 fisiu@opensuse.org
- BuildRequires moved from wxWidgets to wxGTK
* Wed Dec 30 2009 fisiu@opensuse.org
- upstream update to 2.1.0.3584
* Wed Nov 18 2009 fisiu82@gmail.com
- new upstream release 2.0.3365
* Tue Oct 27 2009 fisiu82@gmail.com
- upstream update to 1.0.3035:
  + Compiler annotations and edit margin
  + New Debugger ASCII viewer
  + Better breakpoint handling
  + Get more from gdb!
  + C/C++ static code analysis by CppCheck!
  + Improved Setters / Getters dialog!
* Wed May 27 2009 fisiu82@gmail.com
- upstream update, 1.0.2841
* Mon Apr 20 2009 fisiu82@gmail.com
- upstream update, 1.0.2819
* Fri Mar  6 2009 fisiu82@gmail.com
- initial package, 1.0.2785
